==> 1.0.2.tar.gz: lib/calcula_impostos.dart <==
library calcula_impostos;

import 'Tributacao.dart';

/// A Calculator.

class TributacaoCal {
  static Future<double> calculaImposto(
      {int? idOperacao,
      int? atvEconomica,
      int? idProduto,
      String? dscUF,
      double? valUnitario,
      double? quantidade,
      Future? op,
      Future? res,
      Future? tab}) async {
    List<Map<String, dynamic>> operacao = await op;
    var vlr_icms_pauta = 0.00;
    if (operacao[0]['flg_GeraICMS'] == 1) {
      List<Map<String, dynamic>> registro = await res;

      dynamic valLiquido,
          _baseIcms,
          _aliqIcms,
          _baseIcmsST,
          _aliqImcmsST,
          _baseMVA,
          _valorICMS,
          _valorIcmsST,
          _vlrPauta,
          _mva,
          _tipoCalST,
          _pauta;

      valLiquido = quantidade! * valUnitario!;

      Tributacoes tributacao = new Tributacoes();

      tributacao = Tributacoes.fromJson(registro[0]);
      _vlrPauta = registro[0]['vlr_Pauta'];
      _tipoCalST = registro[0]['tipo_Calst'];
      switch (atvEconomica) {
        //Comercio
        case 0:
          _baseIcms = tributacao.bcIcmsComercio;
          _aliqIcms = tributacao.aliqIcmsComercio + tributacao.aliqFcpComercio;

          _baseIcmsST = tributacao.bcIcmsStComercio;
          _aliqImcmsST =
              tributacao.aliqIcmsStComercio + tributacao.aliqFcpStComercio;

          _baseMVA = tributacao.mvaIcmsComercio;
          break;

        case 1:
          //Industria
          _baseIcms = tributacao.bcIcmsIndustria;
          _aliqIcms =
              tributacao.aliqIcmsIndustria + tributacao.aliqFcpIndustria;

          _baseIcmsST = tributacao.bcIcmsStIndustria;
          _aliqImcmsST =
              tributacao.aliqIcmsStIndustria + tributacao.aliqFcpStIndustria;

          _baseMVA = tributacao.mvaIcmsIndustria;
          break;

        case 2:
          //Consumidor
          _baseIcms = tributacao.bcIcmsConsumidor;
          _aliqIcms =
              tributacao.aliqIcmsConsumidor + tributacao.aliqFcpConsumidor;

          _baseIcmsST = tributacao.bcIcmsStConsumidor;
          _aliqImcmsST =
              tributacao.aliqIcmsStConsumidor + tributacao.aliqFcpStConsumidor;

          _baseMVA = tributacao.mvaIcmsConsumidor;
          break;
        case 3:
          //Produtor
          _baseIcms = tributacao.bcIcmsProdutor;
          _aliqIcms = tributacao.aliqIcmsProdutor + tributacao.aliqFcpProdutor;

          _baseIcmsST = tributacao.bcIcmsStProdutor;
          _aliqImcmsST =
              tributacao.aliqIcmsStProdutor + tributacao.aliqFcpStProdutor;

          _baseMVA = tributacao.mvaIcmsProdutor;
          break;
        case 4:
          //Simples nacional
          _baseIcms = tributacao.bcIcmsSimplesNac;
          _aliqIcms =
              tributacao.aliqIcmsSimplesNac + tributacao.aliqFcpSimplesNac;

          _baseIcmsST = tributacao.bcIcmsStSimplesNac;
          _aliqImcmsST =
              tributacao.aliqIcmsStSimplesNac + tributacao.aliqFcpStSimplesNac;

          _baseMVA = tributacao.mvaIcmsSimplesNac;
          break;

        default:
      }
      var retorno = await tab;
      var base_Ipi = retorno[0]['bc_Ipi'];
      var ali_Ipi = retorno[0]['aliq_Ipi'];
      var incide_IpiNoIcms = retorno[0]['incide_IpiNoIcms'];
      var incide_IpiNotSt = retorno[0]['incide_IpiNoSt'];

      if (_baseIcms == 0) {
        return 0;
      }

      var vlr_ipi = (valLiquido * (base_Ipi / 100)) * (ali_Ipi / 100);
      //Calculo ICMS
      //_valorICMS = valLiquido * (_baseIcms / 100);
      //_valorICMS = _valorICMS * (_aliqIcms / 100);

      if (_tipoCalST == 0) {
        if (incide_IpiNoIcms == 'S') {
          _valorICMS =
              ((valLiquido + vlr_ipi) * (_baseIcms / 100) * (_aliqIcms / 100));
        } else {
          _valorICMS = (valLiquido * (_baseIcms / 100)) * (_aliqIcms / 100);
        }
        if (_baseIcmsST != 0) {
          if (incide_IpiNotSt == 'S') {
            _valorIcmsST = (valLiquido + vlr_ipi) * (_baseIcmsST / 100);
          } else {
            _valorIcmsST = valLiquido * (_baseIcmsST / 100);
          }
          _mva = _valorIcmsST * (_baseMVA / 100);
          _valorIcmsST =
              ((_valorIcmsST + _mva) * (_aliqImcmsST / 100)) - _valorICMS;
        } else {
          _valorIcmsST = 0.0;
        }
      } else {
        _vlrPauta = _pauta * quantidade;

        if (incide_IpiNoIcms == 'S') {
          _valorICMS =
              ((valLiquido + vlr_ipi) * (_baseIcms / 100) * (_aliqIcms / 100));
        } else {
          _valorICMS = (valLiquido * (_baseIcms / 100) * (_aliqIcms / 100));
        }
        if (incide_IpiNotSt == 'S') {
          vlr_icms_pauta = ((_vlrPauta + vlr_ipi) * (_baseIcmsST / 100));
        } else {
          vlr_icms_pauta = (_vlrPauta * (_baseIcmsST / 100));
        }
      }
      vlr_icms_pauta = vlr_icms_pauta * (_aliqImcmsST / 100);
      _valorIcmsST = vlr_icms_pauta - _valorICMS;
      _valorIcmsST = _valorIcmsST < 0 ? 0 : _valorIcmsST;
      print(_valorIcmsST + vlr_ipi);
      return (_valorIcmsST + vlr_ipi);
    } else {
      return 0.00;
    }
  }
}

==> 1.0.3.tar.gz: lib/calcula_impostos.dart <==
library calcula_impostos;

import 'Tributacao.dart';
import 'constante.dart';
import 'dbHelper.dart';

final dbHelper = DatabaseHelper.instance;

class TributacaoCal {
  static Future<double> calculaImposto(
      {int idOperacao,
      int atvEconomica,
      int idProduto,
      String dscUF,
      double valUnitario,
      double quantidade}) async {
    List<Map<String, dynamic>> operacao =
        await Tabela.localizar('Operacoes', 'id_Operacao', '$idOperacao');
    var vlr_icms_pauta = 0.00;
    if (operacao[0]['flg_GeraICMS'] == 1) {
      List<Map<String, dynamic>> registro = await Tabela.execSQL(
          Consulta_Tributacao.replaceAll(':id_Produto', '$idProduto')
              .replaceAll(':UF', '$dscUF'));

      dynamic valLiquido,
          _baseIcms,
          _aliqIcms,
          _baseIcmsST,
          _aliqImcmsST,
          _baseMVA,
          _valorICMS,
          _valorIcmsST,
          _vlrPauta,
          _mva,
          _tipoCalST,
          _pauta;

      valLiquido = quantidade * valUnitario;

      Tributacoes tributacao = new Tributacoes();

      tributacao = Tributacoes.fromJson(registro[0]);
      _vlrPauta = registro[0]['vlr_Pauta'];
      _tipoCalST = registro[0]['tipo_Calst'];
      switch (atvEconomica) {
        //Comercio
        case 0:
          _baseIcms = tributacao.bcIcmsComercio;
          _aliqIcms = tributacao.aliqIcmsComercio + tributacao.aliqFcpComercio;

          _baseIcmsST = tributacao.bcIcmsStComercio;
          _aliqImcmsST =
              tributacao.aliqIcmsStComercio + tributacao.aliqFcpStComercio;

          _baseMVA = tributacao.mvaIcmsComercio;
          break;

        case 1:
          //Industria
          _baseIcms = tributacao.bcIcmsIndustria;
          _aliqIcms =
              tributacao.aliqIcmsIndustria + tributacao.aliqFcpIndustria;

          _baseIcmsST = tributacao.bcIcmsStIndustria;
          _aliqImcmsST =
              tributacao.aliqIcmsStIndustria + tributacao.aliqFcpStIndustria;

          _baseMVA = tributacao.mvaIcmsIndustria;
          break;

        case 2:
          //Consumidor
          _baseIcms = tributacao.bcIcmsConsumidor;
          _aliqIcms =
              tributacao.aliqIcmsConsumidor + tributacao.aliqFcpConsumidor;

          _baseIcmsST = tributacao.bcIcmsStConsumidor;
          _aliqImcmsST =
              tributacao.aliqIcmsStConsumidor + tributacao.aliqFcpStConsumidor;

          _baseMVA = tributacao.mvaIcmsConsumidor;
          break;
        case 3:
          //Produtor
          _baseIcms = tributacao.bcIcmsProdutor;
          _aliqIcms = tributacao.aliqIcmsProdutor + tributacao.aliqFcpProdutor;

          _baseIcmsST = tributacao.bcIcmsStProdutor;
          _aliqImcmsST =
              tributacao.aliqIcmsStProdutor + tributacao.aliqFcpStProdutor;

          _baseMVA = tributacao.mvaIcmsProdutor;
          break;
        case 4:
          //Simples nacional
          _baseIcms = tributacao.bcIcmsSimplesNac;
          _aliqIcms =
              tributacao.aliqIcmsSimplesNac + tributacao.aliqFcpSimplesNac;

          _baseIcmsST = tributacao.bcIcmsStSimplesNac;
          _aliqImcmsST =
              tributacao.aliqIcmsStSimplesNac + tributacao.aliqFcpStSimplesNac;

          _baseMVA = tributacao.mvaIcmsSimplesNac;
          break;

        default:
      }
      var retorno = await Tabela.execSQL(
          ''' SELECT * FROM Produtos WHERE id_Produto =${idProduto}''');
      var base_Ipi = retorno[0]['bc_Ipi'];
      var ali_Ipi = retorno[0]['aliq_Ipi'];
      var incide_IpiNoIcms = retorno[0]['incide_IpiNoIcms'];
      var incide_IpiNotSt = retorno[0]['incide_IpiNoSt'];

      if (_baseIcms == 0) {
        return 0;
      }

      var vlr_ipi = (valLiquido * (base_Ipi / 100)) * (ali_Ipi / 100);

      if (_tipoCalST == 0) {
        if (incide_IpiNoIcms == 'S') {
          _valorICMS =
              ((valLiquido + vlr_ipi) * (_baseIcms / 100) * (_aliqIcms / 100));
        } else {
          _valorICMS = (valLiquido * (_baseIcms / 100)) * (_aliqIcms / 100);
        }
        if (_baseIcmsST != 0) {
          if (incide_IpiNotSt == 'S') {
            _valorIcmsST = (valLiquido + vlr_ipi) * (_baseIcmsST / 100);
          } else {
            _valorIcmsST = valLiquido * (_baseIcmsST / 100);
          }
          _mva = _valorIcmsST * (_baseMVA / 100);
          _valorIcmsST =
              ((_valorIcmsST + _mva) * (_aliqImcmsST / 100)) - _valorICMS;
        } else {
          _valorIcmsST = 0.0;
        }
      } else {
        _vlrPauta = _pauta * quantidade;

        if (incide_IpiNoIcms == 'S') {
          _valorICMS =
              ((valLiquido + vlr_ipi) * (_baseIcms / 100) * (_aliqIcms / 100));
        } else {
          _valorICMS = (valLiquido * (_baseIcms / 100) * (_aliqIcms / 100));
        }
        if (incide_IpiNotSt == 'S') {
          vlr_icms_pauta = ((_vlrPauta + vlr_ipi) * (_baseIcmsST / 100));
        } else {
          vlr_icms_pauta = (_vlrPauta * (_baseIcmsST / 100));
        }
      }
      vlr_icms_pauta = vlr_icms_pauta * (_aliqImcmsST / 100);
      _valorIcmsST = vlr_icms_pauta - _valorICMS;
      _valorIcmsST = _valorIcmsST < 0 ? 0 : _valorIcmsST;
      print(_valorIcmsST + vlr_ipi);
      return (_valorIcmsST + vlr_ipi);
    } else {
      return 0.00;
    }
  }
}

class Tabela {
  static Future<List<Map<String, dynamic>>> execSQL(String sql) async {
    final registros = await dbHelper.executaSQL(sql);
    return registros;
  }

  static executeSQL(String sql) async {
    await dbHelper.executeSQL(sql);
  }

  static Future<List<Map<String, dynamic>>> localizar(
      String tabela, String campo, String valor) async {
    String where = " $campo = '$valor' ";
    final linhasEncontradas = await dbHelper.querySearch(tabela, where);
    return linhasEncontradas;
  }
}
